@@ -14,6 +14,9 @@ class Account:
     downloads_limit: Optional[int] = None
     is_scroll_search_enabled: Optional[bool] = None
     search_params_limit: Optional[int] = 10
+    requests_rate_limit: Optional[int] = None
+    on_demand_scans_remaining: Optional[int] = None
+    on_demand_scans_limit: Optional[int] = None
 
 
 @dataclass_json
@@ -848,7 +851,7 @@ class Report:
 class Abuse:
     reports_num: Optional[int] = None
     score: Optional[int] = None
-    reports:  Optional[List[Report]] = None
+    reports: Optional[List[Report]] = None
 
 
 @dataclass_json
@@ -867,7 +870,10 @@ class GeoData:
     as_num: Optional[int] = None
     as_org: Optional[str] = None
     isp: Optional[str] = None
-    location_data: Optional[LocationData] = None
+    city_name: Optional[str] = None
+    country: Optional[str] = None
+    country_iso_code: Optional[str] = None
+    location: Optional[GeoPoint] = None
 
 
 @dataclass_json
@@ -877,6 +883,7 @@ class SeverityDetails:
     MEDIUM: Optional[int] = None
     LOW: Optional[int] = None
 
+
 @dataclass_json
 @dataclass
 class PtrRecord:
